==> haskell-topograph-1.0.0.2-48-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-topograph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 topograph
version:              1.0.0.2
visibility:           public
id:                   topograph-1.0.0.2-DZNUKaFXTNR9yiUhr63MD1
key:                  topograph-1.0.0.2-DZNUKaFXTNR9yiUhr63MD1
license:              BSD-3-Clause
copyright:            (c) 2018-2019 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/topograph
synopsis:             Directed acyclic graphs.
description:
    Directed acyclic graphs can be sorted topographically.
    Existence of topographic ordering allows writing many graph algorithms efficiently.
    And many graphs, e.g. most dependency graphs are acyclic!

    There are some algorithms built-in: dfs, transpose, transitive closure,
    transitive reduction...
    Some algorithms even become not-so-hard to implement, like a longest path!

category:             Data, Graph
abi:                  63df516e0cd84cd8288ec1a716b3ac26
exposed:              True
exposed-modules:      Topograph
import-dirs:          /usr/lib/ghc-9.2.8/site-local/topograph-1.0.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/topograph-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-topograph
hs-libraries:         HStopograph-1.0.0.2-DZNUKaFXTNR9yiUhr63MD1
depends:
    base-4.16.4.0 base-compat-0.12.2-5hQPtIjgG5LKnb20qwjRWd
    base-orphans-0.8.8.2-8pE3LNPkijIA21wki8CJLW containers-0.6.5.1
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:   /usr/share/doc/haskell-topograph/html/topograph.haddock
haddock-html:         /usr/share/doc/haskell-topograph/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-topograph-1.0.0.2-76.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-topograph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 topograph
version:              1.0.0.2
visibility:           public
id:                   topograph-1.0.0.2-J7Au1NsVg7IL8FHKpFuUkM
key:                  topograph-1.0.0.2-J7Au1NsVg7IL8FHKpFuUkM
license:              BSD-3-Clause
copyright:            (c) 2018-2019 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/topograph
synopsis:             Directed acyclic graphs.
description:
    Directed acyclic graphs can be sorted topographically.
    Existence of topographic ordering allows writing many graph algorithms efficiently.
    And many graphs, e.g. most dependency graphs are acyclic!

    There are some algorithms built-in: dfs, transpose, transitive closure,
    transitive reduction...
    Some algorithms even become not-so-hard to implement, like a longest path!

category:             Data, Graph
abi:                  1822e7217dd63b24bfdc1f8401fa9a7d
exposed:              True
exposed-modules:      Topograph
import-dirs:          /usr/lib/ghc-9.4.8/site-local/topograph-1.0.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/topograph-1.0.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/topograph-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-topograph
hs-libraries:         HStopograph-1.0.0.2-J7Au1NsVg7IL8FHKpFuUkM
depends:
    base-4.17.2.1 base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    base-orphans-0.9.1-H5ZKrdj0NFhGxOpdRcZ2du containers-0.6.7
    vector-0.13.2.0-H3MTIE0bxkOEYwCD854O16

haddock-interfaces:   /usr/share/doc/haskell-topograph/html/topograph.haddock
haddock-html:         /usr/share/doc/haskell-topograph/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
